Python Library for controlling RS-UV3 Radio Shield.',
*************************

Includes methods for controlling and configuring most aspects of the RS-UV3
Radio Shield via a Serial Interface.

Most commands operate-on and return Python dictionaries.


Source
======
Github: https://github.com/ampledata/rsuv3

Author
======
Greg Albrecht W2GMD <gba@orionlabs.io>

Copyright
=========
Copyright 2016 Orion Labs, Inc.

License
=======
Apache License, Version 2.0
